==> moengagesdk-4.1.03-sources.jar: com/moengage/push/PushHandler.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.push;

import android.content.Context;
import android.os.Bundle;
import android.support.annotation.WorkerThread;
import java.util.Map;

public interface PushHandler {

    /**
     * (non-JavaDoc)
     *
     * @param context Instance of the application {@link Context}
     * @return GCM token
     * <b>Note : This method should not be called from the main thread</b>
     */
    @WorkerThread void registerForPushToken(Context context);

    /**
     * (non-JavaDoc)
     *
     * Use MoEPushHelper.getInstance().handlePushPayload(Context, Map)
     */
    @Deprecated
    void handlePushPayload(Context context, Bundle extras);

    /**
     * (non-JavaDoc)
     * Starts intent service to offload task from main thread
     *
     * @param context Application Context
     * @param extra parameter which decides the task to be performed
     */
    void offLoadToWorker(Context context, String extra);

    /**
     * Use MoEPushHelper.getInstance().handlePushPayload(Context, Map)
     */
    @Deprecated void handlePushPayload(Context context, Map<String, String> pushPayload);
}

==> moengagesdk-4.1.06-sources.jar: com/moengage/push/PushHandler.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.push;

import android.content.Context;
import android.os.Bundle;
import android.support.annotation.WorkerThread;
import java.util.Map;

public interface PushHandler {

    /**
     * (non-JavaDoc)
     *
     * @param context Instance of the application {@link Context}
     * @return GCM token
     * <b>Note : This method should not be called from the main thread</b>
     */
    @WorkerThread void registerForPushToken(Context context);

    /**
     * (non-JavaDoc)
     *
     * Use MoEPushHelper.getInstance().handlePushPayload(Context, Map)
     */
    @Deprecated
    void handlePushPayload(Context context, Bundle extras);

    /**
     * Use MoEPushHelper.getInstance().handlePushPayload(Context, Map)
     */
    @Deprecated void handlePushPayload(Context context, Map<String, String> pushPayload);

    /**
     * API to support legacy API {@link PushManager#refreshToken(Context, String)}
     */
    void passPushToken(Context context, String pushToken);
}
